"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEsmConfiguration = exports.getCjsConfiguration = void 0;
/*!
 * Copyright (c) Microsoft. All rights reserved.
 * Licensed under the MIT license. See LICENSE file in the project.
 */
const fs_1 = require("fs");
const path_1 = require("path");
const createBabelConfig_1 = require("./createBabelConfig");
const getBrowsersList_1 = require("./getBrowsersList");
const cwd = process.cwd();
const packageJsonPath = path_1.join(cwd, 'package.json');
const packageJson = fs_1.existsSync('package.json') ? require(packageJsonPath) : {};
const babelEsmOverride = path_1.join(cwd, 'babelrc.esm.js');
const babelCjsOverride = path_1.join(cwd, 'babelrc.cjs.js');
const useBuiltIns = packageJson.useBuiltIns || false;
const corejs = packageJson.corejs || (useBuiltIns ? { version: 3 } : undefined);
/**
 * Gets the babel CJS configuration
 * @param env The babel env to use
 */
function getCjsConfiguration(env) {
    if (fs_1.existsSync(babelCjsOverride)) {
        return require(babelCjsOverride);
    }
    return createBabelConfig_1.createBabelConfig('cjs', getBrowsersList_1.getBrowsersList(env, packageJson.browserslist), useBuiltIns, corejs);
}
exports.getCjsConfiguration = getCjsConfiguration;
/**
 * Gets the babel ESM configuration
 * @param env The babel env to use
 */
function getEsmConfiguration(env) {
    if (fs_1.existsSync(babelEsmOverride)) {
        return require(babelEsmOverride);
    }
    return createBabelConfig_1.createBabelConfig('esm', getBrowsersList_1.getBrowsersList(env, packageJson.browserslist), useBuiltIns, corejs);
}
exports.getEsmConfiguration = getEsmConfiguration;
